'use client'

import { useState, useEffect } from 'react'
import { useParams } from 'next/navigation'
import {
  FiPlus, FiMinus, FiTrash2, FiRefreshCw,
  FiCreditCard, FiDollarSign, FiGrid, FiPackage,
  FiShoppingCart, FiCheck, FiPrinter
} from 'react-icons/fi'
import DashboardLayout from '@/components/layout/DashboardLayout'
import { productService, tableService } from '@/services/api'
import { useUser } from '@/contexts/UserContext'
import router from 'next/router'
import Modal from '@/components/ui/Modal'
import { useNotificationStore } from '@/store/useNotificationStore'

export default function TableOrderPage() {
  const params = useParams()
  const { user } = useUser()
  const [selectedCategory, setSelectedCategory] = useState<string | null>(null)
  const [showTransferModal, setShowTransferModal] = useState(false)
  const [showPaymentModal, setShowPaymentModal] = useState(false)
  const [transferTableId, setTransferTableId] = useState('')
  const [products, setProducts] = useState<any[]>([])
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState(false)
  const [tables, setTables] = useState<any[]>([])
  const [table, setTable] = useState<any>(null)
  const [orderData, setOrderData] = useState<any>(null)
  const [paymentSuccess, setPaymentSuccess] = useState(false)
  const [splitCount, setSplitCount] = useState<number>(2)
  
  // Kişi başı tutarı hesapla
  const perPersonAmount = table?.total_price 
    ? Math.ceil((table.total_price / splitCount) * 100) / 100
    : 0

  // Ürünleri çek
  const fetchProducts = async () => {
    try {
      const response = await productService.index(user?.token || '')
      setProducts(response.data.products)
      setLoading(false)
    } catch (err) {
      setError(true)
      setLoading(false)
    }
  }

  const fetchTableDetails = async () => {
    try {
      const response = await tableService.show(params.id as string, user?.token || '')
      console.log('API Response:', response.data)
      setTable(response.data.table)
    } catch (err) {
      console.error('Masa detayları yüklenirken hata:', err)
    }
  }

  const fetchOrderDetails = async () => {
    try {
      const response = await tableService.orderDetails(params.id as string, user?.token || '')
      setOrderData(response.data.order)
      setTable(response.data.table)
    } catch (err) {
      // TODO: Hata durumunda
    }
  }

  // Masaları çekmek için yeni bir fonksiyon ekleyelim
  const fetchTables = async () => {
    try {
      const response = await tableService.index(user?.token || '')
      setTables(response.data.tables)
    } catch (err) {
      console.error('Masalar yüklenirken hata:', err)
    }
  }

  // Sepet state'i
  const [cart, setCart] = useState<{
    id: number;
    name: string;
    price: number;
    quantity: number;
  }[]>([])

  // Toplam tutarı hesapla
  const cartTotal = cart.reduce((sum, item) => sum + (item.price * item.quantity), 0)

  const handleAddToCart = (product: any) => {
    setCart(prev => {
      const existing = prev.find(item => item.id === product.id)
      if (existing) {
        return prev.map(item =>
          item.id === product.id
            ? { ...item, quantity: item.quantity + 1 }
            : item
        )
      }
      return [...prev, { ...product, quantity: 1 }]
    })
  }

  const handleUpdateCartQuantity = (productId: number, change: number) => {
    setCart(prev => {
      return prev.map(item => {
        if (item.id === productId) {
          const newQuantity = item.quantity + change
          return newQuantity > 0 ? { ...item, quantity: newQuantity } : item
        }
        return item
      }).filter(item => item.quantity > 0)
    })
  }

  const handleRemoveFromCart = (productId: number) => {
    setCart(prev => prev.filter(item => item.id !== productId))
  }

  const handleSubmitOrder = async () => {
    try {
      // Sepetteki ürünleri API'nin istediği formata dönüştür
      const orderProducts = cart.map(item => ({
        product_id: item.id,
        quantity: item.quantity
      }))

      // API'ye gönder
      await tableService.addOrder(
        params.id as string, 
        orderProducts,
        user?.token || ''
      )

      // Başarılı olursa sepeti temizle
      setCart([])
      
      alert('Sipariş başarıyla eklendi!')
      fetchOrderDetails()
      
    } catch (err) {
      // Hata durumunda
      console.error('Sipariş eklenirken hata:', err)
      alert('Sipariş eklenirken bir hata oluştu')
    }
  }

  const handleUpdateQuantity = (orderId: number, change: number) => {
    console.log('Miktar güncellendi:', { orderId, change })
  }

  const handleTransferTable = async () => {
    try {
      if (!transferTableId) {
        alert('Lütfen hedef masa seçin')
        return
      }

      await tableService.transfer(
        params.id as string,
        transferTableId,
        user?.token || ''
      )

      // Transfer başarılı olduğunda
      setShowTransferModal(false)
      setTransferTableId('')
      
      // Başarı mesajı göster
      alert('Masa başarıyla aktarıldı')
      
      // Sayfayı yenile
      window.location.href = `/dashboard/tables/${params.id}/order`
      
    } catch (err) {
      console.error('Masa transfer hatası:', err)
      alert('Masa aktarılırken bir hata oluştu')
    }
  }

  const handlePayment = async () => {
    try {
      await tableService.takePayment(Number(params.id), user?.token || '')
      setShowPaymentModal(false)
      setPaymentSuccess(true)
      
    } catch (err) {
      console.error('Ödeme alınırken hata:', err)
      useNotificationStore.getState().showNotification('Ödeme alınırken bir hata oluştu')
    }
  }

  const handlePrintReceipt = async () => {
    try {
      const response = await tableService.receipt(orderData.id as string, user?.token || '')
      
      // Blob'u text'e çevir
      const text = await response.data.text()
      // Text'i JSON'a parse et
      const jsonData = JSON.parse(text)
      
      console.log('Parsed Receipt Data:', jsonData) // Debug için
      
      if (!jsonData || !jsonData.receipt) {
        throw new Error('Fiş içeriği alınamadı')
      }
      
      const receiptText = jsonData.receipt
      
      // Text içeriğini yazdırmak için yeni bir pencere aç
      const printWindow = window.open('', '_blank')
      if (printWindow) {
        printWindow.document.write(`
          <html>
            <head>
              <title>Adisyon</title>
              <style>
                @media print {
                  body { 
                    font-family: monospace;
                    white-space: pre;
                    margin: 0;
                    padding: 20px;
                    font-size: 12px;
                    line-height: 1.2;
                  }
                  @page {
                    size: 80mm auto;  /* Termal yazıcı genişliği */
                    margin: 0;
                  }
                }
              </style>
            </head>
            <body>
              <pre>${receiptText}</pre>
              <script>
                window.onload = function() {
                  window.print();
                  setTimeout(function() { window.close(); }, 500);
                }
              </script>
            </body>
          </html>
        `)
        printWindow.document.close()
      } else {
        throw new Error('Yazdırma penceresi açılamadı')
      }
      
      useNotificationStore.getState().showNotification('Adisyon yazdırılıyor...')
      
    } catch (error) {
      console.error('Adisyon yazdırma hatası:', error)
      useNotificationStore.getState().showNotification('Adisyon yazdırılırken bir hata oluştu')
    }
  }

  // Kategorileri unique olarak al
  const uniqueCategories = Array.from(
    new Set(products.map(p => p.category?.id))
  ).map(categoryId => 
    products.find(p => p.category?.id === categoryId)?.category
  ).filter(Boolean)

  const handleSplitCountChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const value = e.target.value.replace(/^0+/, '') // Baştaki sıfırları temizle
    const numberValue = parseInt(value)
    
    if (!isNaN(numberValue) && numberValue >= 2) {
      setSplitCount(numberValue)
    }
  }

  useEffect(() => {
    if (user?.token) {
      fetchProducts()
      fetchTableDetails()
      fetchOrderDetails()
      fetchTables() // Masaları da çekelim
    }
  }, [user?.token])

  return (
    <DashboardLayout>
      <div className="space-y-6">
        {/* Üst Bilgi Kartları */}
        <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-4 gap-4">
          {/* Masa Bilgisi */}
          <div className="bg-white dark:bg-slate-800 shadow-sm rounded-2xl 
                       border border-slate-200 dark:border-slate-700">
            <div className="flex items-center gap-3 p-4">
              <div className="p-2 bg-fuchsia-50 dark:bg-fuchsia-900/50 rounded-xl">
                <FiGrid className="w-5 h-5 text-fuchsia-500" />
              </div>
              <div>
                <p className="text-sm text-slate-500 dark:text-slate-400">Masa</p>
                <h3 className="text-lg font-semibold text-slate-800 dark:text-white">
                  {table?.name}
                </h3>
              </div>
            </div>
          </div>

          {/* Toplam Tutar */}
          <div className="bg-white dark:bg-slate-800 shadow-sm rounded-2xl 
                       border border-slate-200 dark:border-slate-700">
            <div className="flex items-center gap-3 p-4">
              <div className="p-2 bg-emerald-50 dark:bg-emerald-900/50 rounded-xl">
                <FiDollarSign className="w-5 h-5 text-emerald-500" />
              </div>
              <div>
                <p className="text-sm text-slate-500 dark:text-slate-400">Toplam Tutar</p>
                <h3 className="text-lg font-semibold text-slate-800 dark:text-white">
                  ₺{table?.total_price}
                </h3>
              </div>
            </div>
          </div>

          {/* Ürün Sayısı */}
          <div className="bg-white dark:bg-slate-800 shadow-sm rounded-2xl 
                       border border-slate-200 dark:border-slate-700">
            <div className="flex items-center gap-3 p-4">
              <div className="p-2 bg-blue-50 dark:bg-blue-900/50 rounded-xl">
                <FiPackage className="w-5 h-5 text-blue-500" />
              </div>
              <div>
                <p className="text-sm text-slate-500 dark:text-slate-400">Ürün Sayısı</p>
                <h3 className="text-lg font-semibold text-slate-800 dark:text-white">
                  {orderData?.order_items?.length || 0} adet
                </h3>
              </div>
            </div>
          </div>

          {/* İşlem Butonları */}
          <div className="bg-white dark:bg-slate-800 shadow-sm rounded-2xl 
                       border border-slate-200 dark:border-slate-700">
            <div className="flex items-center gap-2 h-full p-4">
              <button
                onClick={() => setShowTransferModal(true)}
                className="flex items-center justify-center gap-2 px-4 py-3 text-sm font-medium
                         bg-slate-50 dark:bg-slate-700 text-slate-600 dark:text-slate-300
                         hover:bg-slate-100 dark:hover:bg-slate-600 rounded-xl transition-colors"
              >
                <FiRefreshCw className="w-4 h-4" />
                Aktar
              </button>
              
              <button
                onClick={() => setShowPaymentModal(true)}
                className="flex items-center justify-center gap-2 px-4 py-3 text-sm font-medium
                         text-white bg-gradient-to-r from-fuchsia-500 to-purple-600
                         rounded-xl hover:opacity-90 transition-all flex-1"
              >
                <FiCreditCard className="w-4 h-4" />
                Ödeme Al
              </button>
            </div>
          </div>
        </div>

        {/* Ana İçerik */}
        <div className="grid lg:grid-cols-5 gap-6">
          {/* Sol Taraf - Ürünler */}
          <div className="lg:col-span-3 order-2 lg:order-1">
            <div className="bg-white dark:bg-slate-800 shadow-sm rounded-2xl 
                          border border-slate-200 dark:border-slate-700">
              <div className="p-4 border-b border-slate-200 dark:border-slate-700">
                <div className="flex items-center justify-between">
                  <div className="flex items-center gap-2">
                    <FiPackage className="w-5 h-5 text-blue-500" />
                    <h3 className="font-semibold text-slate-800 dark:text-white">
                      Ürünler
                    </h3>
                  </div>
                </div>
                {/* Kategori Tabları */}
                <div className="flex flex-wrap items-center gap-2 mt-4 pb-2">
                  <button
                    onClick={() => setSelectedCategory(null)}
                    className={`px-4 py-2 rounded-xl text-sm font-medium whitespace-nowrap
                             ${!selectedCategory
                        ? 'bg-fuchsia-500 text-white'
                        : 'bg-slate-100 dark:bg-slate-700 text-slate-600 dark:text-slate-300 hover:bg-slate-200 dark:hover:bg-slate-600'
                      } transition-colors`}
                  >
                    Tümü
                  </button>
                  {uniqueCategories.map(category => (
                    <button
                      key={category.id}
                      onClick={() => setSelectedCategory(category.id)}
                      className={`px-4 py-2 rounded-xl text-sm font-medium whitespace-nowrap
                               ${selectedCategory === category.id
                          ? 'bg-fuchsia-500 text-white'
                          : 'bg-slate-100 dark:bg-slate-700 text-slate-600 dark:text-slate-300 hover:bg-slate-200 dark:hover:bg-slate-600'
                        } transition-colors`}
                    >
                      {category.name}
                    </button>
                  ))}
                </div>
              </div>
              <div className="p-4">
                <div className="grid grid-cols-2 sm:grid-cols-3 md:grid-cols-4 gap-3">
                  {loading ? (
                    <div>Yükleniyor...</div>
                  ) : error ? (
                    <div>Bir hata oluştu</div>
                  ) : (
                    products
                      .filter(p => !selectedCategory || p.category?.id === selectedCategory)
                      .map((product) => (
                        <div
                          key={product.id}
                          onClick={() => handleAddToCart(product)}
                          className="bg-white dark:bg-slate-800 rounded-xl p-4 cursor-pointer
                                   hover:shadow-lg transition-all border border-slate-200 dark:border-slate-700"
                        >
                          <img
                            src={`${process.env.NEXT_PUBLIC_API_URL_STORAGE}/${product.image}`}
                            alt={product.name}
                            className="w-full h-24 object-cover rounded-lg mb-3"
                          />
                          <h3 className="font-medium text-slate-800 dark:text-white">
                            {product.name}
                          </h3>
                          <p className="text-sm text-slate-500 dark:text-slate-400 mt-1">
                            ₺{product.price}
                          </p>
                        </div>
                      ))
                  )}
                </div>
              </div>
            </div>
          </div>

          {/* Sağ Taraf - Sepet */}
          <div className="lg:col-span-2 order-1 lg:order-2">
            <div className="bg-white dark:bg-slate-800 shadow-sm rounded-2xl 
                          border border-slate-200 dark:border-slate-700">
              <div className="p-4 border-b border-slate-200 dark:border-slate-700">
                <div className="flex items-center justify-between">
                  <div className="flex items-center gap-2">
                    <FiShoppingCart className="w-5 h-5 text-fuchsia-500" />
                    <h3 className="font-semibold text-slate-800 dark:text-white">
                      Seçilen Ürünler
                    </h3>
                  </div>
                  <span className="text-sm font-medium text-slate-600 dark:text-slate-400">
                    Toplam: ₺{cartTotal.toFixed(2)}
                  </span>
                </div>
              </div>

              <div className="p-4 space-y-3">
                {cart.map((item) => (
                  <div key={item.id}
                    className="flex items-center justify-between p-3 rounded-xl
                                bg-slate-50 dark:bg-slate-700/50 
                                group hover:bg-slate-100/80 dark:hover:bg-slate-700
                                transition-colors">
                    <div className="flex-1">
                      <h4 className="font-medium text-slate-800 dark:text-slate-100">
                        {item.name}
                      </h4>
                      <p className="text-sm text-slate-500 dark:text-slate-400">
                        ₺{item.price.toFixed(2)} × {item.quantity} = ₺{(item.price * item.quantity).toFixed(2)}
                      </p>
                    </div>
                    <div className="flex items-center gap-2">
                      <button
                        onClick={() => handleUpdateCartQuantity(item.id, -1)}
                        className="p-1 rounded-lg hover:bg-white dark:hover:bg-slate-600"
                      >
                        <FiMinus className="w-4 h-4 text-slate-600 dark:text-slate-400" />
                      </button>
                      <span className="w-8 text-center text-slate-800 dark:text-slate-200">
                        {item.quantity}
                      </span>
                      <button
                        onClick={() => handleUpdateCartQuantity(item.id, 1)}
                        className="p-1 rounded-lg hover:bg-white dark:hover:bg-slate-600"
                      >
                        <FiPlus className="w-4 h-4 text-slate-600 dark:text-slate-400" />
                      </button>
                      <button
                        onClick={() => handleRemoveFromCart(item.id)}
                        className="p-1 rounded-lg text-slate-400 
                                 hover:bg-red-50 dark:hover:bg-red-900/20 hover:text-red-500"
                      >
                        <FiTrash2 className="w-4 h-4" />
                      </button>
                    </div>
                  </div>
                ))}

                {cart.length === 0 && (
                  <div className="text-center py-8 text-slate-500">
                    Henüz ürün seçilmedi
                  </div>
                )}
              </div>

              {cart.length > 0 && (
                <div className="p-4 border-t border-slate-200 dark:border-slate-700">
                  <button
                    onClick={handleSubmitOrder}
                    className="w-full px-4 py-2.5 text-sm font-medium text-white
                             bg-gradient-to-r from-fuchsia-500 to-purple-600
                             rounded-xl hover:opacity-90 transition-all
                             flex items-center justify-center gap-2"
                  >
                    <FiCheck className="w-4 h-4" />
                    Siparişi Onayla
                  </button>
                </div>
              )}
            </div>
          </div>
        </div>

        {/* Sipariş Detayı - Altta ve Ortalı */}
        <div className="mt-6 w-full max-w-3xl mx-auto">
          <div className="bg-white dark:bg-slate-800 shadow-sm rounded-2xl 
                        border border-slate-200 dark:border-slate-700">
            <div className="p-4 border-b border-slate-200 dark:border-slate-700">
              <div className="flex items-center justify-between">
                <div className="flex items-center gap-2">
                  <FiGrid className="w-5 h-5 text-blue-500" />
                  <h2 className="font-semibold text-slate-800 dark:text-white">
                    Sipariş Detayı
                  </h2>
                </div>
              </div>
            </div>
            <div className="p-4">
              <div className="space-y-4">
                {orderData?.order_items?.map((item: any) => (
                  <div
                    key={item.id}
                    className="flex flex-col sm:flex-row sm:items-center justify-between 
                             p-3 rounded-xl gap-4 sm:gap-3
                             bg-slate-50/50 dark:bg-slate-700/50 
                             border border-slate-200/50 dark:border-slate-600/50"
                  >
                    <div className="flex flex-col sm:flex-row sm:items-center gap-2 sm:gap-3">
                      <span className="text-sm font-medium text-slate-800 dark:text-white">
                        {item.product.name}
                      </span>
                      <span className="text-xs font-medium px-2 py-1 rounded-lg 
                                    bg-slate-100 dark:bg-slate-600 
                                    text-slate-600 dark:text-slate-300
                                    w-fit">
                        {item.quantity} adet
                      </span>
                    </div>
                    <div className="flex items-center gap-3">
                      <span className="text-sm font-semibold text-slate-800 dark:text-white">
                        ₺{(item.product.price * item.quantity).toFixed(2)}
                      </span>
                    </div>
                  </div>
                ))}
              </div>
            </div>
          </div>
        </div>

        {/* Masa Transfer Modal */}
        {showTransferModal && (
          <div className="fixed inset-0 bg-black/50 backdrop-blur-sm z-50 flex items-center justify-center">
            <div className="bg-white dark:bg-slate-800 rounded-3xl shadow-xl max-w-md w-full mx-4">
              <div className="p-6 border-b border-slate-200 dark:border-slate-700">
                <h2 className="text-lg font-semibold text-slate-800 dark:text-white">
                  Masa Aktar
                </h2>
              </div>
              <div className="p-6 space-y-4">
                <div>
                  <label className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                    Hedef Masa
                  </label>
                  <select
                    value={transferTableId}
                    onChange={(e) => setTransferTableId(e.target.value)}
                    className="w-full px-4 py-2.5 rounded-xl border border-slate-200/50 
                             dark:border-slate-700/50 bg-white/50 dark:bg-slate-700/50 
                             text-slate-800 dark:text-slate-200"
                  >
                    <option value="">Masa Seçin</option>
                    {tables
                      .filter(t => t.id.toString() !== params.id)
                      .map((table) => (
                        <option key={table.id} value={table.id}>
                          {table.name}
                        </option>
                      ))}
                  </select>
                </div>
                <div className="flex justify-end gap-2">
                  <button
                    onClick={() => setShowTransferModal(false)}
                    className="px-4 py-2 text-sm font-medium text-slate-600 dark:text-slate-300"
                  >
                    İptal
                  </button>
                  <button
                    onClick={handleTransferTable}
                    className="px-4 py-2 text-sm font-medium text-white
                             bg-gradient-to-r from-fuchsia-500 to-purple-600
                             rounded-xl hover:opacity-90 transition-all"
                  >
                    Aktar
                  </button>
                </div>
              </div>
            </div>
          </div>
        )}

        {/* Ödeme Modal - Güncellenen kısım */}
        {showPaymentModal && (
          <div className="fixed inset-0 bg-black/50 backdrop-blur-sm z-50 flex items-center justify-center">
            <div className="bg-white dark:bg-slate-800 rounded-3xl shadow-xl max-w-md w-full mx-4">
              <div className="p-6 border-b border-slate-200 dark:border-slate-700">
                <h2 className="text-lg font-semibold text-slate-800 dark:text-white">
                  Ödeme Al
                </h2>
              </div>
              <div className="p-6 space-y-6">
                {/* Toplam Tutar */}
                <div className="text-center">
                  <p className="text-sm text-slate-600 dark:text-slate-400">
                    Toplam Tutar
                  </p>
                  <p className="text-3xl font-bold text-fuchsia-500 dark:text-fuchsia-400 mt-2">
                    ₺{table?.total_price}
                  </p>
                </div>

                {/* Hesap Paylaşımı */}
                <div className="space-y-3">
                  <label className="block text-sm font-medium text-slate-700 dark:text-slate-300">
                    Hesap Paylaşımı
                  </label>
                  <div className="flex items-center gap-3">
                    <button
                      onClick={() => setSplitCount(prev => Math.max(1, prev - 1))}
                      className="p-2 rounded-lg bg-slate-100 dark:bg-slate-700 
                               text-slate-600 dark:text-slate-400 hover:bg-slate-200 
                               dark:hover:bg-slate-600 transition-colors"
                    >
                      <FiMinus className="w-4 h-4" />
                    </button>
                    <input
                      type="text"
                      inputMode="numeric"
                      pattern="[0-9]*"
                      min="1"
                      value={splitCount}
                      onChange={handleSplitCountChange}
                      className="w-20 text-center px-3 py-2 rounded-lg border border-slate-200 
                               dark:border-slate-700 bg-white dark:bg-slate-800
                               text-slate-800 dark:text-white"
                    />
                    <button
                      onClick={() => setSplitCount(prev => prev + 1)}
                      className="p-2 rounded-lg bg-slate-100 dark:bg-slate-700 
                               text-slate-600 dark:text-slate-400 hover:bg-slate-200 
                               dark:hover:bg-slate-600 transition-colors"
                    >
                      <FiPlus className="w-4 h-4" />
                    </button>
                  </div>

                  {/* Kişi Başı Tutar */}
                  <div className="bg-slate-50 dark:bg-slate-700/50 rounded-xl p-4 text-center">
                    <p className="text-sm text-slate-600 dark:text-slate-400">
                      Kişi Başı Tutar
                    </p>
                    <p className="text-xl font-semibold text-slate-800 dark:text-white mt-1">
                      ₺{perPersonAmount}
                    </p>
                  </div>
                </div>

                {/* Butonlar */}
                <div className="flex justify-end gap-2">
                  <button
                    onClick={() => setShowPaymentModal(false)}
                    className="px-4 py-2 text-sm font-medium text-slate-600 dark:text-slate-300
                             hover:text-slate-800 dark:hover:text-white transition-colors"
                  >
                    İptal
                  </button>
                  <button
                    onClick={handlePayment}
                    className="px-4 py-2 text-sm font-medium text-white
                             bg-gradient-to-r from-fuchsia-500 to-purple-600
                             rounded-xl hover:opacity-90 transition-all
                             flex items-center gap-2"
                  >
                    <FiCreditCard className="w-4 h-4" />
                    Ödeme Al
                  </button>
                </div>
              </div>
            </div>
          </div>
        )}
      </div>
      <Modal
        isOpen={paymentSuccess}
        onClose={() => {
          setPaymentSuccess(false)
          window.location.reload()
        }}
        title="Ödeme Başarılı"
        message="Ödeme başarıyla alındı"
        buttons={[
          {
            text: "Yazdır",
            onClick: handlePrintReceipt,
            icon: <FiPrinter className="w-4 h-4" />,
            className: "px-4 py-2 text-sm font-medium text-white bg-gradient-to-r from-fuchsia-500 to-purple-600 rounded-xl hover:opacity-90 transition-all flex items-center gap-2"
          },
          {
            text: "Kapat",
            onClick: () => {
              setPaymentSuccess(false)
              window.location.reload()
            },
            className: "px-4 py-2 text-sm font-medium text-slate-600 dark:text-slate-300 hover:text-slate-800 dark:hover:text-white transition-colors"
          }
        ]}
      />
    </DashboardLayout>
  )
} 